@@ -234,7 +234,7 @@ module Sequel
         private
 
         # Recognize the registered database range types.
-        def schema_column_type(db_type)
+        def schema_range_type(db_type)
           @pg_range_schema_types[db_type] || super
         end
 
@@ -494,8 +494,8 @@ module Sequel
         case k
         when nil
           ''
-        when Date, Time
-          ds.literal(k)[1...-1]
+        when Time, Date
+          ds.literal_date_or_time(k, true)
         when Integer, Float
           k.to_s
         when BigDecimal
